@@ -2,7 +2,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "bewaveddolphin.h"
-#include "ui_bewaveddolphin.h"
+#include "bewaveddolphin_ui.h"
 
 #include "clockdialog.h"
 #include "common.h"
@@ -129,7 +129,7 @@ void DolphinGraphicsView::wheelEvent(QWheelEvent *event)
 
 BewavedDolphin::BewavedDolphin(Scene *scene, const bool askConnection, MainWindow *parent)
     : QMainWindow(parent)
-    , m_ui(new Ui::BewavedDolphin)
+    , m_ui(std::make_unique<BewavedDolphin_Ui>())
     , m_mainWindow(parent)
     , m_externalScene(scene)
     , m_askConnection(askConnection)
@@ -191,7 +191,6 @@ BewavedDolphin::BewavedDolphin(Scene *scene, const bool askConnection, MainWindo
 BewavedDolphin::~BewavedDolphin()
 {
     Settings::setValue("beWavedDolphin/geometry", saveGeometry());
-    delete m_ui;
 }
 
 void BewavedDolphin::loadPixmaps()
@@ -242,7 +241,7 @@ void BewavedDolphin::loadFromTerminal()
     const auto wordList(str.split(','));
 
     if (wordList.size() < 2) {
-        throw Pandaception("");
+        throw PANDACEPTION("");
     }
 
     int rows = wordList.at(0).toInt();
@@ -253,7 +252,7 @@ void BewavedDolphin::loadFromTerminal()
     }
 
     if ((cols < 2) || (cols > 2048)) {
-        throw Pandaception("");
+        throw PANDACEPTION("");
     }
 
     setLength(cols, false);
@@ -263,7 +262,7 @@ void BewavedDolphin::loadFromTerminal()
         const auto wordList2(str.split(','));
 
         if (wordList2.size() < cols) {
-            throw Pandaception("");
+            throw PANDACEPTION("");
         }
 
         for (int col = 0; col < cols; ++col) {
@@ -296,7 +295,7 @@ void BewavedDolphin::loadElements()
     const auto elements = Common::sortGraphicElements(m_externalScene->elements());
 
     if (elements.isEmpty()) {
-        throw Pandaception(tr("Could not load enough elements for the simulation."));
+        throw PANDACEPTION("Could not load enough elements for the simulation.");
     }
 
     for (auto *elm : elements) {
@@ -323,7 +322,7 @@ void BewavedDolphin::loadElements()
     });
 
     if (m_inputs.isEmpty() || m_outputs.isEmpty()) {
-        throw Pandaception(tr("Could not load enough elements for the simulation."));
+        throw PANDACEPTION("Could not load enough elements for the simulation.");
     }
 }
 
@@ -434,12 +433,6 @@ void BewavedDolphin::loadSignals(QStringList &inputLabels, QStringList &outputLa
 }
 
 void BewavedDolphin::run()
-{
-    run2();
-    run2();
-}
-
-void BewavedDolphin::run2()
 {
     qCDebug(zero) << "Creating class to pause main window simulator while creating waveform.";
     SimulationBlocker simulationBlocker(m_simulation);
@@ -463,7 +456,6 @@ void BewavedDolphin::run2()
 
         qCDebug(four) << "Updating the values of the circuit logic based on current input values.";
         m_simulation->update();
-        m_simulation->update();
 
         qCDebug(four) << "Setting the computed output values to the waveform results.";
         row = m_inputPorts;
@@ -512,11 +504,11 @@ void BewavedDolphin::resizeScene()
 
     if (newWidth > 4000 or newHeight > 4000) {
         on_actionResetZoom_triggered();
-        throw Pandaception(tr("Waveform would be too big! Resetting zoom."));
+        throw PANDACEPTION("Waveform would be too big! Resetting zoom.");
     }
 
-    m_signalTableView->resize(newWidth / (m_scale * 0.8),
-                              newHeight / (m_scale * 0.8));
+    m_signalTableView->resize(static_cast<int>(newWidth / (m_scale * 0.8)),
+                              static_cast<int>(newHeight / (m_scale * 0.8)));
     m_scene->setSceneRect(m_scene->itemsBoundingRect());
 }
 
@@ -568,11 +560,11 @@ void BewavedDolphin::createZeroElement(const int row, const int col, const bool
     m_model->setData(index, 0, Qt::DisplayRole);
 
     if (m_type == PlotType::Number) {
-        m_model->setData(index, Qt::AlignCenter, Qt::TextAlignmentRole);
+        m_model->setData(index, static_cast<uint>(Qt::AlignCenter), Qt::TextAlignmentRole);
     }
 
     if (m_type == PlotType::Line) {
-        m_model->setData(index, Qt::AlignLeft, Qt::TextAlignmentRole);
+        m_model->setData(index, static_cast<uint>(Qt::AlignLeft), Qt::TextAlignmentRole);
 
         const auto previousIndex = index.siblingAtColumn(col - 1);
         const bool hasPreviousItem = previousIndex.isValid();
@@ -612,11 +604,11 @@ void BewavedDolphin::createOneElement(const int row, const int col, const bool i
     m_model->setData(index, 1, Qt::DisplayRole);
 
     if (m_type == PlotType::Number) {
-        m_model->setData(index, Qt::AlignCenter, Qt::TextAlignmentRole);
+        m_model->setData(index, static_cast<uint>(Qt::AlignCenter), Qt::TextAlignmentRole);
     }
 
     if (m_type == PlotType::Line) {
-        m_model->setData(index, Qt::AlignLeft, Qt::TextAlignmentRole);
+        m_model->setData(index, static_cast<uint>(Qt::AlignLeft), Qt::TextAlignmentRole);
 
         const auto previousIndex = index.siblingAtColumn(col - 1);
         const bool hasPreviousItem = previousIndex.isValid();
@@ -670,7 +662,7 @@ void BewavedDolphin::saveToTxt(QTextStream &stream)
 {
     on_actionCombinational_triggered();
 
-    const int truthTableSize = std::pow(2, m_inputPorts);
+    const int truthTableSize = static_cast<int>(std::pow(2, m_inputPorts));
     setLength(truthTableSize, false);
 
     for (int row = 0; row < m_inputs.size(); ++row) {
@@ -779,7 +771,7 @@ void BewavedDolphin::on_actionSetClockWave_triggered()
     const auto ranges = m_signalTableView->selectionModel()->selection();
 
     if (ranges.isEmpty()) {
-        throw Pandaception(tr("No cells selected."));
+        throw PANDACEPTION("No cells selected.");
     }
 
     const int firstCol = sectionFirstColumn(ranges);
@@ -812,7 +804,7 @@ void BewavedDolphin::on_actionSetClockWave_triggered()
 
 void BewavedDolphin::on_actionCombinational_triggered()
 {
-    const int truthTableSize = std::min(2048., std::pow(2, m_inputPorts));
+    const int truthTableSize = static_cast<int>(std::min(2048., std::pow(2, m_inputPorts)));
 
     if (m_length < truthTableSize) {
         setLength(truthTableSize, false);
@@ -828,8 +820,8 @@ void BewavedDolphin::on_actionCombinational_triggered()
             createElement(row, col, value);
         }
 
-        halfClockPeriod = std::min(clockPeriod, 524'288);
-        clockPeriod = std::min(2 * clockPeriod, 1'048'576);
+        halfClockPeriod = std::min(clockPeriod, 524288);
+        clockPeriod = std::min(2 * clockPeriod, 1048576);
     }
 
     m_edited = true;
@@ -891,7 +883,7 @@ void BewavedDolphin::on_actionZoomOut_triggered()
     m_view.zoomOut();
 
     for (int col = 0; col < m_signalTableView->model()->columnCount(); ++col) {
-        m_signalTableView->setColumnWidth(col, m_signalTableView->columnWidth(col) / m_scale);
+        m_signalTableView->setColumnWidth(col, static_cast<int>(m_signalTableView->columnWidth(col) / m_scale));
     }
 
     resizeScene();
@@ -903,7 +895,7 @@ void BewavedDolphin::on_actionZoomIn_triggered()
     m_view.zoomIn();
 
     for (int col = 0; col < m_signalTableView->model()->columnCount(); ++col) {
-        m_signalTableView->setColumnWidth(col, m_signalTableView->columnWidth(col) * m_scale);
+        m_signalTableView->setColumnWidth(col, static_cast<int>(m_signalTableView->columnWidth(col) * m_scale));
     }
 
     resizeScene();
@@ -954,7 +946,7 @@ void BewavedDolphin::on_actionClear_triggered()
 
 void BewavedDolphin::on_actionAutoCrop_triggered()
 {
-    setLength(std::pow(2, m_inputs.length()), true);
+    setLength(static_cast<int>(std::pow(2, m_inputs.length())), true);
 }
 
 void BewavedDolphin::on_actionCopy_triggered()
@@ -1060,8 +1052,8 @@ void BewavedDolphin::paste(const QItemSelection &ranges, QDataStream &stream)
         quint64 row;  stream >> row;
         quint64 col;  stream >> col;
         quint64 data_; stream >> data_;
-        const int newRow = static_cast<int>(firstRow + row);
-        const int newCol = static_cast<int>(firstCol + col);
+        const int newRow = static_cast<int>(static_cast<quint64>(firstRow) + row);
+        const int newCol = static_cast<int>(static_cast<quint64>(firstCol) + col);
 
         if ((newRow < m_inputPorts) && (newCol < m_model->columnCount())) {
             createElement(newRow, newCol, static_cast<int>(data_));
@@ -1131,7 +1123,7 @@ void BewavedDolphin::save(const QString &fileName)
     QSaveFile file(fileName);
 
     if (!file.open(QIODevice::WriteOnly)) {
-        throw Pandaception(tr("Error opening file: ") + file.errorString());
+        throw PANDACEPTION("Error opening file: %1", file.errorString());
     }
 
     if (fileName.endsWith(".dolphin")) {
@@ -1145,7 +1137,7 @@ void BewavedDolphin::save(const QString &fileName)
     }
 
     if (!file.commit()) {
-        throw Pandaception(tr("Error saving file: ") + file.errorString());
+        throw PANDACEPTION("Error saving file: %1", file.errorString());
     }
 }
 
@@ -1241,14 +1233,14 @@ void BewavedDolphin::load(const QString &fileName)
     QFile file(fileName);
 
     if (!file.exists()) {
-        throw Pandaception(tr("File \"%1\" does not exist!").arg(fileName));
+        throw PANDACEPTION("File \"%1\" does not exist!", fileName);
     }
 
     qCDebug(zero) << "File exists.";
 
     if (!file.open(QIODevice::ReadOnly)) {
         qCDebug(zero) << "Could not open file in ReadOnly mode: " << file.errorString();
-        throw Pandaception(tr("Could not open file in ReadOnly mode: ") + file.errorString() + ".");
+        throw PANDACEPTION("Could not open file in ReadOnly mode: %1", file.errorString());
     }
 
     if (fileName.endsWith(".dolphin")) {
@@ -1267,7 +1259,7 @@ void BewavedDolphin::load(const QString &fileName)
         m_currentFile = QFileInfo(fileName);
     } else {
         qCDebug(zero) << "Format not supported. Could not open file: " << fileName;
-        throw Pandaception(tr("Format not supported. Could not open file: ") + fileName);
+        throw PANDACEPTION("Format not supported. Could not open file: %1", fileName);
     }
 
     qCDebug(zero) << "Closing file.";
@@ -1286,7 +1278,7 @@ void BewavedDolphin::load(QDataStream &stream)
     }
 
     if ((cols < 2) || (cols > 2048)) {
-        throw Pandaception(tr("Invalid number of columns."));
+        throw PANDACEPTION("Invalid number of columns.");
     }
 
     setLength(static_cast<int>(cols), false);
@@ -1314,7 +1306,7 @@ void BewavedDolphin::load(QFile &file)
     }
 
     if ((cols < 2) || (cols > 2048)) {
-        throw Pandaception(tr("Invalid number of columns."));
+        throw PANDACEPTION("Invalid number of columns.");
     }
 
     setLength(cols, false);
@@ -1410,7 +1402,7 @@ void BewavedDolphin::on_actionExportToPdf_triggered()
     QPainter painter;
 
     if (!painter.begin(&printer)) {
-        throw Pandaception(tr("Could not print this circuit to PDF."));
+        throw PANDACEPTION("Could not print this circuit to PDF.");
     }
 
     m_scene->render(&painter, QRectF(), m_scene->sceneRect().adjusted(-64, -64, 64, 64));
