@@ -1,4 +1,4 @@
-// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
+// Copyright 2015 - 2025, GIBIS-UNIFESP and the wiRedPanda contributors
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
@@ -14,23 +14,25 @@ public:
 
     QString genericProperties() override;
     bool isOn(const int port = 0) const override;
+    float delay() const override;
     float frequency() const override;
     void load(QDataStream &stream, QMap<quint64, QNEPort *> &portMap, const QVersionNumber version) override;
-    void resetClock();
+    void resetClock(const std::chrono::steady_clock::time_point &globalTime);
     void save(QDataStream &stream) const override;
+    void setDelay(const float delay) override;
     void setFrequency(const float freq) override;
     void setOff() override;
     void setOn() override;
     void setOn(const bool value, const int port = 0) override;
     void setSkin(const bool defaultSkin, const QString &fileName) override;
-    void updateClock();
+    void updateClock(const std::chrono::steady_clock::time_point &globalTime);
 
 private:
     bool m_isOn = false;
-    bool m_reset = true;
+    double m_delay = 0;
     double m_frequency = 0;
-    std::chrono::duration<float, std::milli> m_interval{};
-    std::chrono::steady_clock::time_point m_timePoint;
+    std::chrono::microseconds m_interval;
+    std::chrono::steady_clock::time_point m_startTime;
 };
 
 Q_DECLARE_METATYPE(Clock)
