@@ -87,7 +87,7 @@ int Led::colorIndex()
     std::bitset<4> indexBit;
 
     for (int i = 0; i < inputSize(); ++i) {
-        indexBit[i] = static_cast<bool>(inputPort(i)->status() == Status::Active);
+        indexBit[static_cast<std::size_t>(i)] = static_cast<bool>(inputPort(i)->status() == Status::Active);
     }
 
     const int index = static_cast<int>(indexBit.to_ulong());
@@ -99,6 +99,11 @@ int Led::colorIndex()
     case 2: index2 = (index == 3) ? 25 : 18 + index; break;
     case 3: index2 = 18 + index;                     break;
     case 4: index2 = 10 + index;                     break;
+
+    default:
+        // Handle unexpected input sizes gracefully
+        index2 = index;  // Simple fallback
+        break;
     }
 
     return index2;
