@@ -1,15 +1,10 @@
-// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
+// Copyright 2015 - 2025, GIBIS-UNIFESP and the wiRedPanda contributors
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "line.h"
 
 #include "globalproperties.h"
 
-namespace
-{
-    int id = qRegisterMetaType<Line>();
-}
-
 Line::Line(QGraphicsItem *parent)
     : GraphicElement(ElementType::Line, ElementGroup::Other, ":/misc/line.svg", tr("LINE"), tr("Line"), 0, 0, 0, 0, parent)
 {
