@@ -1,15 +1,10 @@
-// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
+// Copyright 2015 - 2025, GIBIS-UNIFESP and the wiRedPanda contributors
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "text.h"
 
 #include "globalproperties.h"
 
-namespace
-{
-    int id = qRegisterMetaType<Text>();
-}
-
 Text::Text(QGraphicsItem *parent)
     : GraphicElement(ElementType::Text, ElementGroup::Other, ":/misc/text.png", tr("TEXT"), tr("Text"), 0, 0, 0, 0, parent)
 {
