@@ -2,7 +2,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "mainwindow.h"
-#include "ui_mainwindow.h"
+#include "mainwindow_ui.h"
 
 #include "bewaveddolphin.h"
 #include "codegenerator.h"
@@ -26,20 +26,24 @@
 #include <QDebug>
 #include <QDesktopServices>
 #include <QFileDialog>
+#include <QLocale>
 #include <QLoggingCategory>
 #include <QMessageBox>
 #include <QPdfWriter>
 #include <QPrinter>
+#include <QResource>
 #include <QSaveFile>
 #include <QShortcut>
 #include <QTemporaryFile>
 #include <QTranslator>
 
+#ifdef Q_OS_MAC
 #include <QSvgRenderer>
 
 void ensureSvgUsage() {
     QSvgRenderer dummy; // for macdeployqt to add libqsvg.dylib
 }
+#endif
 
 #ifdef Q_OS_WASM
 #include <emscripten/emscripten.h>
@@ -53,13 +57,45 @@ void ensureSvgUsage() {
 
 MainWindow::MainWindow(const QString &fileName, QWidget *parent)
     : QMainWindow(parent)
-    , m_ui(new Ui::MainWindow)
+    , m_ui(std::make_unique<MainWindow_Ui>())
 {
     qCDebug(zero) << "wiRedPanda Version = " APP_VERSION " OR " << GlobalProperties::version;
     m_ui->setupUi(this);
 
     qCDebug(zero) << "Settings fileName: " << Settings::fileName();
-    loadTranslation(Settings::value("language").toString());
+
+    // Get language from settings, or auto-detect from system if not set
+    QString language = Settings::value("language").toString();
+    if (language.isEmpty()) {
+        // Auto-detect system language
+        QLocale systemLocale = QLocale::system();
+        QString systemLanguage = systemLocale.name(); // e.g., "en_US", "pt_BR"
+        QString baseLanguage = systemLanguage.split('_').first(); // e.g., "en", "pt"
+
+        qCDebug(zero) << "Auto-detected system locale:" << systemLanguage;
+
+        // Check if we have translation for this language
+        const auto availableLanguages = getAvailableLanguages();
+
+        // First try the full locale (e.g., "pt_BR")
+        if (availableLanguages.contains(systemLanguage)) {
+            language = systemLanguage;
+        }
+        // Then try the base language (e.g., "pt")
+        else if (availableLanguages.contains(baseLanguage)) {
+            language = baseLanguage;
+        }
+        // Fall back to English
+        else {
+            qCDebug(zero) << "No translation available for" << systemLanguage << "or" << baseLanguage << ", falling back to English";
+            language = "en";
+        }
+
+        qCDebug(zero) << "Selected language:" << language;
+    }
+
+    loadTranslation(language);
+    populateLanguageMenu();
 
     connect(m_ui->tab, &QTabWidget::currentChanged,    this, &MainWindow::tabChanged);
     connect(m_ui->tab, &QTabWidget::tabCloseRequested, this, &MainWindow::closeTab);
@@ -118,7 +154,7 @@ MainWindow::MainWindow(const QString &fileName, QWidget *parent)
     qCDebug(zero) << "Disabling Arduino export.";
     m_ui->actionExportToArduino->setEnabled(false);
 
-    QPixmapCache::setCacheLimit(100'000);
+    QPixmapCache::setCacheLimit(100000);
 
     qCDebug(zero) << "Adding examples to menu";
     QDir examplesDir("examples");
@@ -130,8 +166,8 @@ MainWindow::MainWindow(const QString &fileName, QWidget *parent)
             auto *action = new QAction(entry);
 
             connect(action, &QAction::triggered, this, [this] {
-                if (auto *action = qobject_cast<QAction *>(sender())) {
-                    loadPandaFile("examples/" + action->text());
+                if (auto *senderAction = qobject_cast<QAction *>(sender())) {
+                    loadPandaFile("examples/" + senderAction->text());
                 }
             });
 
@@ -144,7 +180,7 @@ MainWindow::MainWindow(const QString &fileName, QWidget *parent)
     }
 
     // Shortcuts
-    auto *searchShortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_F), this);
+    auto *searchShortcut = new QShortcut(QKeySequence("Ctrl+F"), this);
     auto *prevMainPropShortcut = new QShortcut(QKeySequence("["), this);
     auto *nextMainPropShortcut = new QShortcut(QKeySequence("]"), this);
     auto *prevSecndPropShortcut = new QShortcut(QKeySequence("{"), this);
@@ -164,9 +200,9 @@ MainWindow::MainWindow(const QString &fileName, QWidget *parent)
     connect(m_ui->actionAbout,            &QAction::triggered,        this,                &MainWindow::on_actionAbout_triggered);
     connect(m_ui->actionAboutQt,          &QAction::triggered,        this,                &MainWindow::on_actionAboutQt_triggered);
     connect(m_ui->actionAboutThisVersion, &QAction::triggered,        this,                &MainWindow::aboutThisVersion);
+    connect(m_ui->actionReportTranslationError, &QAction::triggered,  this,                &MainWindow::on_actionReportTranslationError_triggered);
     connect(m_ui->actionChangeTrigger,    &QAction::triggered,        m_ui->elementEditor, &ElementEditor::changeTriggerAction);
     connect(m_ui->actionDarkTheme,        &QAction::triggered,        this,                &MainWindow::on_actionDarkTheme_triggered);
-    connect(m_ui->actionEnglish,          &QAction::triggered,        this,                &MainWindow::on_actionEnglish_triggered);
     connect(m_ui->actionExit,             &QAction::triggered,        this,                &MainWindow::on_actionExit_triggered);
     connect(m_ui->actionExportToArduino,  &QAction::triggered,        this,                &MainWindow::on_actionExportToArduino_triggered);
     connect(m_ui->actionExportToImage,    &QAction::triggered,        this,                &MainWindow::on_actionExportToImage_triggered);
@@ -182,7 +218,6 @@ MainWindow::MainWindow(const QString &fileName, QWidget *parent)
     connect(m_ui->actionNew,              &QAction::triggered,        this,                &MainWindow::on_actionNew_triggered);
     connect(m_ui->actionOpen,             &QAction::triggered,        this,                &MainWindow::on_actionOpen_triggered);
     connect(m_ui->actionPlay,             &QAction::toggled,          this,                &MainWindow::on_actionPlay_toggled);
-    connect(m_ui->actionPortuguese,       &QAction::triggered,        this,                &MainWindow::on_actionPortuguese_triggered);
     connect(m_ui->actionReloadFile,       &QAction::triggered,        this,                &MainWindow::on_actionReloadFile_triggered);
     connect(m_ui->actionRename,           &QAction::triggered,        m_ui->elementEditor, &ElementEditor::renameAction);
     connect(m_ui->actionResetZoom,        &QAction::triggered,        this,                &MainWindow::on_actionResetZoom_triggered);
@@ -193,7 +228,6 @@ MainWindow::MainWindow(const QString &fileName, QWidget *parent)
     connect(m_ui->actionSaveAs,           &QAction::triggered,        this,                &MainWindow::on_actionSaveAs_triggered);
     connect(m_ui->actionSelectAll,        &QAction::triggered,        this,                &MainWindow::on_actionSelectAll_triggered);
     connect(m_ui->actionShortcutsAndTips, &QAction::triggered,        this,                &MainWindow::on_actionShortcuts_and_Tips_triggered);
-    connect(m_ui->actionSpanish,          &QAction::triggered,        this,                &MainWindow::on_actionSpanish_triggered);
     connect(m_ui->actionWaveform,         &QAction::triggered,        this,                &MainWindow::on_actionWaveform_triggered);
     connect(m_ui->actionWires,            &QAction::triggered,        this,                &MainWindow::on_actionWires_triggered);
     connect(m_ui->actionZoomIn,           &QAction::triggered,        this,                &MainWindow::on_actionZoomIn_triggered);
@@ -207,7 +241,6 @@ MainWindow::MainWindow(const QString &fileName, QWidget *parent)
 
 MainWindow::~MainWindow()
 {
-    delete m_ui;
 }
 
 void MainWindow::loadAutosaveFiles()
@@ -377,7 +410,7 @@ int MainWindow::confirmSave(const bool multiple)
 
     const QString fileName = m_currentFile.fileName().isEmpty() ? tr("New Project") : m_currentFile.fileName();
 
-    msgBox.setText(fileName + tr(" has been modified. \nDo you want to save your changes?"));
+    msgBox.setText(fileName + tr(" has been modified.\nDo you want to save your changes?"));
     msgBox.setWindowModality(Qt::WindowModal);
     msgBox.setDefaultButton(QMessageBox::Yes);
     return msgBox.exec();
@@ -505,7 +538,7 @@ void MainWindow::on_actionAbout_triggered()
            "<li> Rodrigo Torres </li>"
            "<li> Prof. Fábio Cappabianco, Ph.D. </li>"
            "</ul>"
-           "<p> wiRedPanda is currently maintained by Prof. Fábio Cappabianco, Ph.D., João Pedro M. Oliveira, Matheus R. Esteves e Maycon A. Santana.</p>"
+           "<p> wiRedPanda is currently maintained by Prof. Fábio Cappabianco, Ph.D., João Pedro M. Oliveira, Matheus R. Esteves and Maycon A. Santana.</p>"
            "<p> Please file a report at our GitHub page if bugs are found or if you wish for a new functionality to be implemented.</p>"
            "<p><a href=\"http://gibis-unifesp.github.io/wiRedPanda/\">Visit our website!</a></p>")
             .arg(QApplication::applicationVersion()));
@@ -544,6 +577,11 @@ void MainWindow::on_actionAboutQt_triggered()
     QMessageBox::aboutQt(this);
 }
 
+void MainWindow::on_actionReportTranslationError_triggered()
+{
+    QDesktopServices::openUrl(QUrl("https://hosted.weblate.org/projects/wiredpanda/wiredpanda"));
+}
+
 bool MainWindow::closeFiles()
 {
     while (m_ui->tab->count() != 0) {
@@ -784,6 +822,8 @@ void MainWindow::connectTab()
     m_currentTab->view()->setFastMode(m_ui->actionFastMode->isChecked());
     m_ui->actionZoomIn->setEnabled(m_currentTab->view()->canZoomIn());
     m_ui->actionZoomOut->setEnabled(m_currentTab->view()->canZoomOut());
+
+    ElementFactory::setLastId(m_currentTab->lastId());
 }
 
 WorkSpace *MainWindow::currentTab() const
@@ -909,13 +949,13 @@ void MainWindow::exportToArduino(QString fileName)
     }
 
     if (fileName.isEmpty()) {
-        throw Pandaception(tr("Missing file name."));
+        throw PANDACEPTION("Missing file name.");
     }
 
     auto elements = m_currentTab->scene()->elements();
 
     if (elements.isEmpty()) {
-        throw Pandaception(tr("The .panda file is empty."));
+        throw PANDACEPTION("The .panda file is empty.");
     }
 
     SimulationBlocker simulationBlocker(m_currentTab->simulation());
@@ -936,7 +976,7 @@ void MainWindow::exportToArduino(QString fileName)
 void MainWindow::exportToWaveFormFile(const QString &fileName)
 {
     if (fileName.isEmpty()) {
-        throw Pandaception(tr("Missing file name."));
+        throw PANDACEPTION("Missing file name.");
     }
 
     auto *bewavedDolphin = new BewavedDolphin(m_currentTab->scene(), false, this);
@@ -1083,7 +1123,7 @@ void MainWindow::on_actionExportToPdf_triggered()
     QPainter painter;
 
     if (!painter.begin(&printer)) {
-        throw Pandaception(tr("Could not print this circuit to PDF."));
+        throw PANDACEPTION("Could not print this circuit to PDF.");
     }
 
     auto *scene = m_currentTab->scene();
@@ -1136,7 +1176,7 @@ void MainWindow::on_actionExportToImage_triggered()
 void MainWindow::retranslateUi()
 {
     ElementFactory::clearCache();
-    m_ui->retranslateUi(this);
+    m_ui->retranslateUi();
     m_ui->elementEditor->retranslateUi();
 
     const auto items = m_ui->tabElements->findChildren<ElementLabel *>();
@@ -1188,51 +1228,279 @@ void MainWindow::loadTranslation(const QString &language)
 
     // ---------------------------------------------
 
-    QString pandaFile;
-    QString qtFile;
+    // Dynamic translation loading based on available files
+    QString pandaFile = QString(":/translations/wpanda_%1.qm").arg(language);
+    QString qtFile = QString(":/translations/qt_%1.qm").arg(language);
 
-    if (language == "pt_BR") {
-        pandaFile = ":/translations/wpanda_pt_BR.qm";
-        qtFile = ":/translations/qt_pt_BR.qm";
-    }
-
-    if (language == "es") {
-        pandaFile = ":/translations/wpanda_es.qm";
-        qtFile = ":/translations/qt_es.qm";
-    }
-
-    if (!pandaFile.isEmpty()) {
+    // Check if wiRedPanda translation exists
+    QResource pandaResource(pandaFile);
+    if (pandaResource.isValid()) {
         m_pandaTranslator = new QTranslator(this);
 
         if (!m_pandaTranslator->load(pandaFile) || !qApp->installTranslator(m_pandaTranslator)) {
-            throw Pandaception(tr("Error loading wiRedPanda translation!"));
+            qCWarning(zero) << "Failed to load wiRedPanda translation for" << language << ", falling back to English";
+            delete m_pandaTranslator;
+            m_pandaTranslator = nullptr;
+            // Fallback to English
+            if (language != "en") {
+                loadTranslation("en");
+                return;
+            }
         }
     }
 
-    if (!qtFile.isEmpty()) {
+    // Check if Qt translation exists
+    QResource qtResource(qtFile);
+    if (qtResource.isValid()) {
         m_qtTranslator = new QTranslator(this);
 
         if (!m_qtTranslator->load(qtFile) || !qApp->installTranslator(m_qtTranslator)) {
-            throw Pandaception(tr("Error loading Qt translation!"));
+            qCWarning(zero) << "Failed to load Qt translation for" << language << ", continuing without Qt translation";
+            delete m_qtTranslator;
+            m_qtTranslator = nullptr;
         }
     }
 
     retranslateUi();
 }
 
-void MainWindow::on_actionEnglish_triggered()
+QStringList MainWindow::getAvailableLanguages() const
 {
-    loadTranslation("en");
+    QStringList languages;
+
+    // Always include English as it's the default
+    languages << "en";
+
+    // Dynamically discover all available wpanda translation files
+    // Get all resources in the translations directory
+    QDir translationsDir(":/translations");
+    if (translationsDir.exists()) {
+        QStringList qmFiles = translationsDir.entryList({"wpanda_*.qm"}, QDir::Files);
+
+        for (const QString &file : qmFiles) {
+            // Extract language code from filename (e.g., "wpanda_fr.qm" -> "fr")
+            QString langCode = file;
+            langCode.remove("wpanda_");
+            langCode.remove(".qm");
+
+            // Verify the resource actually exists and is valid
+            QString resourcePath = QString(":/translations/%1").arg(file);
+            QResource resource(resourcePath);
+
+            if (resource.isValid() && !langCode.isEmpty()) {
+                languages << langCode;
+            }
+        }
+    } else {
+        // Fallback: Try all possible language patterns if directory listing fails
+        // This covers edge cases where QDir doesn't work with Qt resources
+        const QStringList languagePatterns = {
+            "ar", "bg", "bn", "cs", "da", "de", "el", "es", "et", "fa", "fi", "fr",
+            "he", "hi", "hr", "hu", "id", "it", "ja", "ko", "lt", "lv", "ms", "nb",
+            "nl", "pl", "pt", "pt_BR", "ro", "ru", "sk", "sv", "th", "tr", "uk",
+            "vi", "zh_Hans", "zh_Hant"
+        };
+
+        for (const QString &langCode : languagePatterns) {
+            QString resourcePath = QString(":/translations/wpanda_%1.qm").arg(langCode);
+            QResource resource(resourcePath);
+
+            if (resource.isValid()) {
+                languages << langCode;
+            }
+        }
+    }
+
+    // Remove duplicates and sort
+    languages.removeDuplicates();
+    languages.sort();
+    return languages;
 }
 
-void MainWindow::on_actionPortuguese_triggered()
+void MainWindow::populateLanguageMenu()
 {
-    loadTranslation("pt_BR");
+    // Clear existing actions from the UI menu
+    m_ui->menuLanguage->clear();
+
+    const auto availableLanguages = getAvailableLanguages();
+    auto *languageGroup = new QActionGroup(this);
+    languageGroup->setExclusive(true);
+
+    for (const QString &langCode : availableLanguages) {
+        auto *action = new QAction(getLanguageDisplayName(langCode), this);
+        action->setCheckable(true);
+        action->setData(langCode);
+
+        // Set the flag icon for the language
+        action->setIcon(QIcon(getLanguageFlagIcon(langCode)));
+
+        // Check if this is the current language
+        if (langCode == Settings::value("language").toString() ||
+           (langCode == "en" && Settings::value("language").toString().isEmpty())) {
+            action->setChecked(true);
+        }
+
+        languageGroup->addAction(action);
+        m_ui->menuLanguage->addAction(action);
+
+        connect(action, &QAction::triggered, this, [this, langCode]() {
+            loadTranslation(langCode);
+        });
+    }
 }
 
-void MainWindow::on_actionSpanish_triggered()
+QString MainWindow::getLanguageDisplayName(const QString &langCode) const
 {
-    loadTranslation("es");
+    // Use Qt's built-in locale system to get native language names
+    QLocale locale(langCode);
+
+    // Special handling for some language codes that need specific locales
+    if (langCode == "pt_BR") {
+        locale = QLocale(QLocale::Portuguese, QLocale::Brazil);
+    }
+
+    // Get the native language name (e.g., "Deutsch" for German)
+    QString nativeName = locale.nativeLanguageName();
+
+    // If we have a country-specific variant, add the country name
+    if (langCode.contains('_') || langCode == "pt_BR") {
+#if QT_VERSION < QT_VERSION_CHECK(6, 2, 0)
+        QString nativeCountryName = locale.nativeCountryName();
+#else
+        QString nativeCountryName = locale.nativeTerritoryName();
+#endif
+        if (!nativeCountryName.isEmpty() && nativeCountryName != nativeName) {
+            nativeName += QString(" (%1)").arg(nativeCountryName);
+        }
+    }
+
+    // Fallback to language code if Qt doesn't have the name
+    if (nativeName.isEmpty()) {
+        // Manual fallbacks for languages Qt might not fully support
+        static const QMap<QString, QString> fallbackNames = {
+            {"bn", "বাংলা"},
+            {"fa", "فارسی"},
+            {"he", "עברית"},
+            {"th", "ไทย"}
+        };
+        nativeName = fallbackNames.value(langCode, langCode);
+    }
+
+    // Ensure proper capitalization for the first letter
+    if (!nativeName.isEmpty() && nativeName.at(0).isLetter()) {
+        nativeName[0] = nativeName.at(0).toUpper();
+    }
+
+    return nativeName;
+}
+
+QString MainWindow::getLanguageFlagIcon(const QString &langCode) const
+{
+    // Use Qt's locale system to determine the appropriate country flag
+    QLocale locale(langCode);
+
+    // Special handling for specific language variants
+    if (langCode == "pt") {
+        locale = QLocale(QLocale::Portuguese, QLocale::Portugal);
+    }
+
+    // Map Qt country codes to our flag resource names
+    static const QMap<QLocale::Country, QString> countryToFlag = {
+        {QLocale::SaudiArabia, ":/toolbar/arabic.svg"},          // Arabic
+        {QLocale::Bulgaria, ":/toolbar/bulgarian.svg"},          // Bulgarian
+        {QLocale::Bangladesh, ":/toolbar/bangladesh.svg"},       // Bengali
+        {QLocale::CzechRepublic, ":/toolbar/czech.svg"},        // Czech
+        {QLocale::Denmark, ":/toolbar/danish.svg"},             // Danish
+        {QLocale::Germany, ":/toolbar/german.svg"},             // German
+        {QLocale::Greece, ":/toolbar/greek.svg"},               // Greek
+        {QLocale::UnitedStates, ":/toolbar/usa.svg"},           // English
+        {QLocale::Spain, ":/toolbar/spanish.svg"},              // Spanish
+        {QLocale::Estonia, ":/toolbar/estonian.svg"},           // Estonian
+        {QLocale::Iran, ":/toolbar/iranian.svg"},               // Persian/Farsi
+        {QLocale::Finland, ":/toolbar/finnish.svg"},            // Finnish
+        {QLocale::France, ":/toolbar/french.svg"},              // French
+        {QLocale::Israel, ":/toolbar/hebrew.svg"},              // Hebrew
+        {QLocale::India, ":/toolbar/hindi.svg"},                // Hindi
+        {QLocale::Croatia, ":/toolbar/croatian.svg"},           // Croatian
+        {QLocale::Hungary, ":/toolbar/hungarian.svg"},          // Hungarian
+        {QLocale::Indonesia, ":/toolbar/indonesian.svg"},       // Indonesian
+        {QLocale::Italy, ":/toolbar/italian.svg"},              // Italian
+        {QLocale::Japan, ":/toolbar/japanese.svg"},             // Japanese
+        {QLocale::SouthKorea, ":/toolbar/korean.svg"},          // Korean
+        {QLocale::Lithuania, ":/toolbar/lithuanian.svg"},       // Lithuanian
+        {QLocale::Latvia, ":/toolbar/latvian.svg"},             // Latvian
+        {QLocale::Malaysia, ":/toolbar/malaysian.svg"},         // Malay
+        {QLocale::Norway, ":/toolbar/norwegian.svg"},           // Norwegian
+        {QLocale::Netherlands, ":/toolbar/dutch.svg"},          // Dutch
+        {QLocale::Poland, ":/toolbar/polish.svg"},              // Polish
+        {QLocale::Portugal, ":/toolbar/portuguese.svg"},        // Portuguese
+        {QLocale::Brazil, ":/toolbar/brasil.svg"},              // Portuguese (Brazil)
+        {QLocale::Romania, ":/toolbar/romanian.svg"},           // Romanian
+        {QLocale::Russia, ":/toolbar/russian.svg"},             // Russian
+        {QLocale::Slovakia, ":/toolbar/slovak.svg"},            // Slovak
+        {QLocale::Sweden, ":/toolbar/swedish.svg"},             // Swedish
+        {QLocale::Thailand, ":/toolbar/thai.svg"},              // Thai
+        {QLocale::Turkey, ":/toolbar/turkish.svg"},             // Turkish
+        {QLocale::Ukraine, ":/toolbar/ukrainian.svg"},          // Ukrainian
+        {QLocale::Vietnam, ":/toolbar/vietnamese.svg"},         // Vietnamese
+        {QLocale::China, ":/toolbar/chinese.svg"},              // Chinese Simplified
+        {QLocale::Taiwan, ":/toolbar/chinese_traditional.svg"}  // Chinese Traditional
+    };
+
+    // Get the flag for the locale's country
+#if QT_VERSION < QT_VERSION_CHECK(6, 2, 0)
+    QString flagIcon = countryToFlag.value(locale.country(), ":/toolbar/default.svg");
+#else
+    QString flagIcon = countryToFlag.value(locale.territory(), ":/toolbar/default.svg");
+#endif
+
+    // Fallback for languages where Qt might not detect the country correctly
+    if (flagIcon == ":/toolbar/default.svg") {
+        static const QMap<QString, QString> languageFallbacks = {
+            {"ar", ":/toolbar/arabic.svg"},
+            {"bg", ":/toolbar/bulgarian.svg"},
+            {"bn", ":/toolbar/bangladesh.svg"},
+            {"cs", ":/toolbar/czech.svg"},
+            {"da", ":/toolbar/danish.svg"},
+            {"de", ":/toolbar/german.svg"},
+            {"el", ":/toolbar/greek.svg"},
+            {"en", ":/toolbar/usa.svg"},
+            {"es", ":/toolbar/spanish.svg"},
+            {"et", ":/toolbar/estonian.svg"},
+            {"fa", ":/toolbar/iranian.svg"},
+            {"fi", ":/toolbar/finnish.svg"},
+            {"fr", ":/toolbar/french.svg"},
+            {"he", ":/toolbar/hebrew.svg"},
+            {"hi", ":/toolbar/hindi.svg"},
+            {"hr", ":/toolbar/croatian.svg"},
+            {"hu", ":/toolbar/hungarian.svg"},
+            {"id", ":/toolbar/indonesian.svg"},
+            {"it", ":/toolbar/italian.svg"},
+            {"ja", ":/toolbar/japanese.svg"},
+            {"ko", ":/toolbar/korean.svg"},
+            {"lt", ":/toolbar/lithuanian.svg"},
+            {"lv", ":/toolbar/latvian.svg"},
+            {"ms", ":/toolbar/malaysian.svg"},
+            {"nb", ":/toolbar/norwegian.svg"},
+            {"nl", ":/toolbar/dutch.svg"},
+            {"pl", ":/toolbar/polish.svg"},
+            {"pt", ":/toolbar/portuguese.svg"},
+            {"pt_BR", ":/toolbar/brasil.svg"},
+            {"ro", ":/toolbar/romanian.svg"},
+            {"ru", ":/toolbar/russian.svg"},
+            {"sk", ":/toolbar/slovak.svg"},
+            {"sv", ":/toolbar/swedish.svg"},
+            {"th", ":/toolbar/thai.svg"},
+            {"tr", ":/toolbar/turkish.svg"},
+            {"uk", ":/toolbar/ukrainian.svg"},
+            {"vi", ":/toolbar/vietnamese.svg"},
+            {"zh_Hans", ":/toolbar/chinese.svg"},
+            {"zh_Hant", ":/toolbar/chinese_traditional.svg"}
+        };
+        flagIcon = languageFallbacks.value(langCode, ":/toolbar/default.svg");
+    }
+
+    return flagIcon;
 }
 
 void MainWindow::on_actionPlay_toggled(const bool checked)
@@ -1312,6 +1580,11 @@ void MainWindow::updateTheme()
     switch (ThemeManager::theme()) {
     case Theme::Dark:  m_ui->actionDarkTheme->setChecked(true); break;
     case Theme::Light: m_ui->actionLightTheme->setChecked(true); break;
+
+    default:
+        // Handle unexpected theme values - fallback to Light theme
+        m_ui->actionLightTheme->setChecked(true);
+        break;
     }
 
     m_ui->tabElements->setTabIcon(2, QIcon(DFlipFlop::pixmapPath()));
@@ -1412,7 +1685,7 @@ void MainWindow::on_pushButtonAddIC_clicked()
     }
 
     if (!m_currentTab->fileInfo().isReadable()) {
-        throw Pandaception(tr("Save file first."));
+        throw PANDACEPTION("Save file first.");
     }
 
     QFileDialog fileDialog;
@@ -1465,7 +1738,7 @@ void MainWindow::removeICFile(const QString &icFileName)
     QFile file(GlobalProperties::currentDir + "/" + icFileName);
 
     if (!file.remove()) {
-        throw Pandaception(tr("Error removing file: ") + file.errorString());
+        throw PANDACEPTION("Error removing file: %1", file.errorString());
     }
 
     updateICList();
