@@ -339,7 +339,7 @@ void Scene::prevMainPropShortcut()
 
         case ElementType::Clock:
             if (element->hasFrequency())
-                element->setFrequency(element->frequency() - 0.5);
+                element->setFrequency(element->frequency() - 0.5f);
             break;
 
         case ElementType::Buzzer:
@@ -391,7 +391,7 @@ void Scene::nextMainPropShortcut()
 
         case ElementType::Clock:
             if (element->hasFrequency())
-                element->setFrequency(element->frequency() + 0.5);
+                element->setFrequency(element->frequency() + 0.5f);
             break;
 
         case ElementType::Buzzer:
