@@ -39,7 +39,6 @@
 #include <QPushButton>
 #include <QRegularExpression>
 #include <QScrollBar>
-#include <QSet>
 #include <QSettings>
 #include <QShortcut>
 #include <QStandardItemModel>
@@ -51,7 +50,4 @@
 #include <QVector>
 #include <QWidget>
 #include <QtGlobal>
-#include <cmath>
-#include <memory>
-#include <stdexcept>
 #endif
